@@ -40,12 +40,7 @@
 #'
 #' @export
 #'
-init.dcm <- function(s.num,
-                     i.num,
-                     r.num,
-                     s.num.g2,
-                     i.num.g2,
-                     r.num.g2,
+init.dcm <- function(s.num, i.num, r.num, s.num.g2, i.num.g2, r.num.g2,
                      ...) {
 
   # Get arguments
@@ -116,14 +111,8 @@ init.dcm <- function(s.num,
 #'
 #' @export
 #'
-init.icm <- function(s.num,
-                     i.num,
-                     r.num,
-                     s.num.g2,
-                     i.num.g2,
-                     r.num.g2,
-                     status.rand = TRUE,
-                     ...) {
+init.icm <- function(s.num, i.num, r.num, s.num.g2, i.num.g2, r.num.g2,
+                     status.rand = TRUE, ...) {
 
   # Get arguments
   p <- list()
@@ -188,13 +177,8 @@ init.icm <- function(s.num,
 #'
 #' @export
 #'
-init.net <- function(i.num,
-                     r.num,
-                     i.num.m2,
-                     r.num.m2,
-                     status.vector,
-                     status.rand = TRUE,
-                     ...) {
+init.net <- function(i.num, r.num, i.num.m2, r.num.m2,
+                     status.vector, status.rand = TRUE, ...) {
 
   # Get arguments
   p <- list()
